# labb

UI components library for Django perfectionists.

## Installation

```bash
# Basic installation
pip install labbui
# or both labb and labbicons
pip install labbui[icons]
```

## Documentation

Full documentation is available at [https://labb.io/docs](https://labb.io/docs).

## License

MIT License
